Documentation
¶
Index ¶
Constants ¶
const ( Sqlite3 databaseEngine = iota + 1 Postgres Beanstalkd Stdout )
Variables ¶
var NotImplementedError = errors.New("Function not implemented")
Functions ¶
This section is empty.
Types ¶
type Database ¶
type Database interface {
Engine() databaseEngine
DoesTorrentExist(infoHash []byte) (bool, error)
AddNewTorrent(infoHash []byte, name string, files []File) error
Close() error
// GetNumberOfTorrents returns the number of torrents saved in the database. Might be an
// approximation.
GetNumberOfTorrents() (uint, error)
// QueryTorrents returns @pageSize amount of torrents,
// * that are discovered before @discoveredOnBefore
// * that match the @query if it's not empty, else all torrents
// * ordered by the @orderBy in ascending order if @ascending is true, else in descending order
// after skipping (@page * @pageSize) torrents that also fits the criteria above.
//
// On error, returns (nil, error), otherwise a non-nil slice of TorrentMetadata and nil.
QueryTorrents(
query string,
epoch int64,
orderBy OrderingCriteria,
ascending bool,
limit uint,
lastOrderedValue *float64,
lastID *uint64,
) ([]TorrentMetadata, error)
// GetTorrents returns the TorrentExtMetadata for the torrent of the given InfoHash. Will return
// nil, nil if the torrent does not exist in the database.
GetTorrent(infoHash []byte) (*TorrentMetadata, error)
GetFiles(infoHash []byte) ([]File, error)
GetStatistics(from string, n uint) (*Statistics, error)
}
type Granularity ¶
type Granularity int
const ( Year Granularity = iota Month Week Day Hour )
func ParseISO8601 ¶
func ParseISO8601(s string) (*time.Time, Granularity, error)
ParseISO8601 is **not** a function to parse all and every kind of valid ISO 8601 date, nor it's intended to be, since we don't need that.
type OrderingCriteria ¶
type OrderingCriteria uint8
const ( ByRelevance OrderingCriteria = iota ByTotalSize ByDiscoveredOn ByNFiles ByNSeeders ByNLeechers ByUpdatedOn )
type SimpleTorrentSummary ¶
type Statistics ¶
type Statistics struct {
NDiscovered map[string]uint64 `json:"nDiscovered"`
NFiles map[string]uint64 `json:"nFiles"`
TotalSize map[string]uint64 `json:"totalSize"`
}
func NewStatistics ¶
func NewStatistics() (s *Statistics)
type TorrentMetadata ¶
type TorrentMetadata struct {
ID uint64 `json:"id"`
InfoHash []byte `json:"infoHash"` // marshalled differently
Name string `json:"name"`
Size uint64 `json:"size"`
DiscoveredOn int64 `json:"discoveredOn"`
NFiles uint `json:"nFiles"`
Relevance float64 `json:"relevance"`
}
func (*TorrentMetadata) MarshalJSON ¶
func (tm *TorrentMetadata) MarshalJSON() ([]byte, error)
Click to show internal directories.
Click to hide internal directories.